:github_url: https://github.com/j-bac/elpigraph-python/tree/master/elpigraph-python/elpigraph/_graph_editing.py#L233-L853



elpigraph.findPaths
===================

.. currentmodule:: elpigraph

.. autofunction:: findPaths